package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Charge;
import com.usky.dxtop.model.Staff;
import com.usky.dxtop.service.ChargeService;
import com.usky.dxtop.service.StaffService;
import com.usky.dxtop.service.api.WxApi;
import com.usky.dxtop.service.config.rabbitmq.ChargeTransConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

/**
 * @author yq
 * @date 2021/9/9 11:05
 */
@Slf4j
@Component
public class ChargeTransMqListener {

    @Autowired
    private ChargeService chargeService;

    @Autowired
    private StaffService staffService;

    @Autowired
    private WxApi wxApi;
    @RabbitListener(queues = ChargeTransConfig.NAME, containerFactory = ChargeTransConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String routingKey = message.getMessageProperties().getReceivedRoutingKey();
            log.info(routingKey);
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            log.info("charge_trans_produce:接受到的消息"+s);
            Charge charge = JSONObject.parseObject(s, Charge.class);
            chargeService.saveOrUpdate(charge);
            //更新用户余额
            Staff staff = staffService.one(null, null, charge.getCard());
            staff.setBalance(charge.getBalance());
            staffService.updateById(staff);
            if (StringUtils.isNotBlank(staff.getOpenId())){
                Map<String, Object> map = new HashMap<>();
                Map<String, Object> firstMap = new HashMap<>();
                firstMap.put("value","支付成功");
                map.put("first",firstMap);
                wxApi.sendMessageApi(staff.getOpenId(),map,wxApi.getToken(WxApi.APP_ID,WxApi.SECRET));
            }
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
        } finally {

        }
    }
}
